==> python-django-braces_1.4.0.orig.tar.gz: django-braces-1.4.0/braces/views/__init__.py <==
from __future__ import absolute_import

from ._access import (
    AnonymousRequiredMixin,
    GroupRequiredMixin,
    LoginRequiredMixin,
    MultiplePermissionsRequiredMixin,
    PermissionRequiredMixin,
    StaffuserRequiredMixin,
    SuperuserRequiredMixin,
    UserPassesTestMixin
)
from ._ajax import (
    AjaxResponseMixin,
    JSONRequestResponseMixin,
    JSONResponseMixin,
    JsonRequestResponseMixin
)
from ._forms import (
    CsrfExemptMixin,
    FormInvalidMessageMixin,
    FormMessagesMixin,
    FormValidMessageMixin,
    MessageMixin,
    SuccessURLRedirectListMixin,
    UserFormKwargsMixin,
    _MessageAPIWrapper
)
from ._other import (
    AllVerbsMixin,
    CanonicalSlugDetailMixin,
    SetHeadlineMixin,
    StaticContextMixin
)
from ._queries import (
    OrderableListMixin,
    PrefetchRelatedMixin,
    SelectRelatedMixin
)

__all__ = [
    'AjaxResponseMixin',
    'AllVerbsMixin',
    'AnonymousRequiredMixin',
    'CanonicalSlugDetailMixin',
    'CsrfExemptMixin',
    'FormInvalidMessageMixin',
    'FormMessagesMixin',
    'FormValidMessageMixin',
    'GroupRequiredMixin',
    'JSONRequestResponseMixin',
    'JsonRequestResponseMixin',
    'JSONResponseMixin',
    'LoginRequiredMixin',
    'MessageMixin',
    'MultiplePermissionsRequiredMixin',
    'OrderableListMixin',
    'PermissionRequiredMixin',
    'PrefetchRelatedMixin',
    'SelectRelatedMixin',
    'SetHeadlineMixin',
    'StaffuserRequiredMixin',
    'StaticContextMixin',
    'SuccessURLRedirectListMixin',
    'SuperuserRequiredMixin',
    'UserFormKwargsMixin',
    'UserPassesTestMixin'
]

==> python-django-braces_1.9.0.orig.tar.gz: django-braces-1.9.0/braces/views/__init__.py <==
from __future__ import absolute_import

from ._access import (
    AnonymousRequiredMixin,
    GroupRequiredMixin,
    LoginRequiredMixin,
    MultiplePermissionsRequiredMixin,
    PermissionRequiredMixin,
    StaffuserRequiredMixin,
    SuperuserRequiredMixin,
    UserPassesTestMixin,
    SSLRequiredMixin,
    RecentLoginRequiredMixin
)
from ._ajax import (
    AjaxResponseMixin,
    JSONRequestResponseMixin,
    JSONResponseMixin,
    JsonRequestResponseMixin
)
from ._forms import (
    CsrfExemptMixin,
    FormInvalidMessageMixin,
    FormMessagesMixin,
    FormValidMessageMixin,
    MessageMixin,
    SuccessURLRedirectListMixin,
    UserFormKwargsMixin,
    _MessageAPIWrapper
)
from ._other import (
    AllVerbsMixin,
    CanonicalSlugDetailMixin,
    SetHeadlineMixin,
    StaticContextMixin
)
from ._queries import (
    OrderableListMixin,
    PrefetchRelatedMixin,
    SelectRelatedMixin
)

__all__ = [
    'AjaxResponseMixin',
    'AllVerbsMixin',
    'AnonymousRequiredMixin',
    'CanonicalSlugDetailMixin',
    'CsrfExemptMixin',
    'FormInvalidMessageMixin',
    'FormMessagesMixin',
    'FormValidMessageMixin',
    'GroupRequiredMixin',
    'JSONRequestResponseMixin',
    'JsonRequestResponseMixin',
    'JSONResponseMixin',
    'LoginRequiredMixin',
    'MessageMixin',
    'MultiplePermissionsRequiredMixin',
    'OrderableListMixin',
    'PermissionRequiredMixin',
    'PrefetchRelatedMixin',
    'SelectRelatedMixin',
    'SetHeadlineMixin',
    'StaffuserRequiredMixin',
    'StaticContextMixin',
    'SuccessURLRedirectListMixin',
    'SuperuserRequiredMixin',
    'UserFormKwargsMixin',
    'UserPassesTestMixin',
    'SSLRequiredMixin',
    'RecentLoginRequiredMixin'
]
